version = '0.0.26'
from .table import Datable
import os, sys
start_des = '''
 -------------------------------------------------------------------------------------------------------------
 |                                                                                                           |
 -------------------------------------------------------------------------------------------------------------
               *******          *     ************     *          *******      ***          ********
              *********       ***         **         ***         ***    **    ***          ***
             ***    ***     *****        **        *****        ***   ***    ***          ***
            ***     **    ***  **       **       ***  **       *******      ***          *******
           ***    ***   *********      **      *********      ***    **    ***          ***
          *********   ***      **     **     ***      **     ***    ***   ***          ***
         *******    ***        **    **    ***        **    *********    *********    *********   
         By Ziplux     Version: {}     
 -------------------------------------------------------------------------------------------------------------
 |                                                                                                           |
 -------------------------------------------------------------------------------------------------------------'''.format(version.replace("'",''))

print(start_des)